//------------------------------------------------------------------------
//  HTML MILLING Step Report Format File (report body)
//  NOTE: Formats are driven off of the op SNCS associated with a step.
//------------------------------------------------------------------------

extern integer doff, loff, step_num, outspeed, unspmode, unfdmode;
extern string st_desc, st_notes;
extern float outfeed1, outfeed3, dwellsec, pekdpth1, pekdpth2;

//	Procedure to map unspmode to text string
procedure speed_mode
{
	format ("%s", 
		map(unspmode, [ 1 = "SFM", 2 = "RPM", 11 = "m/min", 12 = "RPM"]));
}

// Procedure to map unfdmode to text string
procedure feed_mode
{
	format ("%s", 
		map(unfdmode, [ 1 = "IPR", 2 = "IPM", 11 = "mm/r", 12 = "mm/min"]));
}

//	Step specific procedures below
//	Each "step" is a table nested in the larger report table

//	Add a row to tool report banner with gview screen cap
procedure stprpt_image
{
	format("\t\t\t<tr class=\"stepreport\">\n");
	format("\t\t\t\t<td class=\"stepreportimg\" align=\"center\">");
	format("<center><img class=\"report\" src=\"%s\" height=\"600\" width=\"800\" /></center></td>\n", get_name(report_image_get(1, 800, 600)));
	format("\t\t\t</tr>\n");
}

//	Create the initial Step Report table - this creates the table banner and establishes the table
procedure step_header
{
	format("\t\t<table class=\"stepreport\">\n");

	//	report table banner row
	format("\t\t\t<tr class=\"stepreport\">\n");
	format("\t\t\t\t<th class=\"stepreport\"><H2>Step Report</H2></th>\n");
	format("\t\t\t</tr>\n");

	// add bitmap of gview if requested
	call_if_report_image(stprpt_image);
}

//	Close out the Step Report table - add footer row if needed
procedure step_footer
{
	format("\t\t</table>\n");
}

//	Wrapper procedures used by step report tables
//	These exist only to make it easier to create the standard nested table rows, cells, and tables

procedure create_stcell
{
	format("\t\t\t<tr class=\"stepreport\">\n");
	format("\t\t\t\t<td class=\"stepreport\">\n");

	//	create inner table for record data
	format("\t\t\t\t\t<table class=\"stprpt2\">\n");
}

procedure close_stcell
{
	format("\t\t\t\t\t</table>\n");
	format("\t\t\t\t</td>\n");
	format("\t\t\t</tr>\n");
}


//	Generic Step table output
procedure section_1030000
{
	//	create a Row in the main Step Report table, for the nested Step table
	call (create_stcell);

	//	Output Step record data
	//	Step # and Step description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%d</td>\n", step_num);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step Desc:</th>\n");	
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", st_desc);
	format("\t\t\t\t\t\t</tr>\n");

	//	step notes
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=6>%s</td>\n", st_notes);
	format("\t\t\t\t\t\t</tr>\n");

	//	tool # and tl desc
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool No:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", tl_num);	
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", tl_desc);	
	format("\t\t\t\t\t\t</tr>\n");

	//	Doff and Loff
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Doff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", doff);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Loff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-d</td>\n", loff);
	format("\t\t\t\t\t\t</tr>\n");

	//	Feed, Speed, and plunge feed
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Speed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d ", outspeed);
	call (speed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%-0.4f ", outfeed1);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Plunge Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-0.4f ", outfeed3);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t</tr>\n");

	// close out inner table and row
	call (close_stcell);
}

//	Milling Step table output
procedure section_1030100
{
	//	create a Row in the main Step Report table, for the nested Step table
	call(create_stcell);

	//	Step # and Description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%-d</td>\n", step_num);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", st_desc);
	format("\t\t\t\t\t\t</tr>\n");

	//	 step notes
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=6>%s</td>\n", st_notes);
	format("\t\t\t\t\t\t</tr>\n");

	//	 tool # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool No:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", tl_num);	
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", tl_desc);	
	format("\t\t\t\t\t\t</tr>\n");

	//	 doff and loff
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Doff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", doff);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Loff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-d</td>\n", loff);
	format("\t\t\t\t\t\t</tr>\n");
 
	//	speed, feed, and plunge speed
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Speed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d ", outspeed);
	call (speed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%-0.4f ", outfeed1);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Plunge Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-0.4f ", outfeed3);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t</tr>\n");

	// close out inner table and row
	call(close_stcell);
}


//	Generic Hole Making Step table output
procedure section_1030200
{
	//	create a Row in the main Step Report table, for the nested Step table
	call(create_stcell);

	//	Step # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%d</td>\n", step_num);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", st_desc);
	format("\t\t\t\t\t\t</tr>\n");

	//	step notes
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=6>%s</td>\n", st_notes);
	format("\t\t\t\t\t\t</tr>\n");

	//	tool # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool No:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", tl_num);	
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", tl_desc);	
	format("\t\t\t\t\t\t</tr>\n");

	//	doff and loff
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Doff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", doff);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Loff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-d</td>\n", loff);
	format("\t\t\t\t\t\t</tr>\n");
 
	//	speed, feed, and dwell
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Speed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d ", outspeed);
	call (speed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%-0.4f ", outfeed1);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Dwell:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-0.4f</td>\n", dwellsec);
	format("\t\t\t\t\t\t</tr>\n");

	// close out inner table and row
	call(close_stcell);
}


//	Peck Drilling Making Step table output
procedure section_1030203
{
	//	create a Row in the main Step Report table, for the nested Step table
	call(create_stcell);

	//	Step # and Description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%d</td>\n", step_num);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", st_desc);
	format("\t\t\t\t\t\t</tr>\n");

	//	step notes
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=6>%s</td>\n", st_notes);
	format("\t\t\t\t\t\t</tr>\n");

	//	Tool # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool No:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", tl_num);	
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", tl_desc);	
	format("\t\t\t\t\t\t</tr>\n");

	//	doff and loff
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Doff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", doff);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Loff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-d</td>\n", loff);
	format("\t\t\t\t\t\t</tr>\n");
 
	//	speed, feed, and dwell
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Speed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d ", outspeed);
	call (speed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%-0.4f ", outfeed1);
	call (feed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Dwell:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-0.4f</td>\n", dwellsec);
	format("\t\t\t\t\t\t</tr>\n");

	//	first peck, peck increment
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">First Peck:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-8.4f</td>\n", pekdpth1);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Peck Incr:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-8.4f</td>\n", pekdpth2);
	format("\t\t\t\t\t\t</tr>\n");

	// close out inner table and row
	call(close_stcell);
}


//	Tapping Step table output
procedure section_1030206
{
	//	create a Row in the main Step Report table, for the nested Step table
	call(create_stcell);

	//	step # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" width=\"15%%\">%d</td>\n", step_num);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Step Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", st_desc);
	format("\t\t\t\t\t\t</tr>\n");

	//	step notes
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=6>%s</td>\n", st_notes);
	format("\t\t\t\t\t\t</tr>\n");

	//	tool # and description
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool No:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", tl_num);	
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Tool Desc:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%s</td>\n", tl_desc);	
	format("\t\t\t\t\t\t</tr>\n");

	//	doff and loff
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Doff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d</td>\n", doff);
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Loff:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-d</td>\n", loff);
	format("\t\t\t\t\t\t</tr>\n");
 
	//	speed, feed, dwell
	format("\t\t\t\t\t\t<tr class=\"stprpt2\">\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Speed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">%-d ", outspeed);
	call (speed_mode);
	format("</td>\n");
	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Feed:</th>\n");
	format("\t\t\t\t\t\t\t<td class=\"stprpt2\" colspan=3>%-0.4f ", outfeed1);
	call (feed_mode);
	format("</td>\n");
//	format("\t\t\t\t\t\t\t<th class=\"stprpt2\">Dwell:</th>\n");
//	format("\t\t\t\t\t\t\t<td class=\"stprpt2\">N/A</td>\n");
	format("\t\t\t\t\t\t</tr>\n");

	// close out inner table and row
	call(close_stcell);
}
